@@ -1,4 +1,6 @@
 /*
+ * Copyright (C) 2003-2011 The Xfce Development Team
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
@@ -9,10 +11,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,12 +34,13 @@
 #include <pango/pango-font.h>
 
 #include <libxfce4util/libxfce4util.h>
+#include <libxfcegui4/libxfcegui4.h>
 
-char *states[] = {
+static const char *states[] = {
     "normal", "active", "prelight", "selected", "insensitive", NULL
 };
 
-char *names[] = {
+static const char *names[] = {
     "fg", "bg", "text", "base", "light", "dark", "mid", NULL
 };
 
@@ -51,9 +53,9 @@ char *names[] = {
 #define GTKSTYLE_MID   6
 
 static gint
-state_value (gchar * s)
+state_value (const gchar * s)
 {
-    gchar *t;
+    const gchar *t;
     gint u;
 
     t = states[0];
@@ -71,9 +73,9 @@ state_value (gchar * s)
 }
 
 static gint
-name_value (gchar * s)
+name_value (const gchar * s)
 {
-    gchar *t;
+    const gchar *t;
     gint u;
 
     t = names[0];
@@ -119,7 +121,7 @@ print_colors (GtkWidget * win, GdkColor * x, int n)
 }
 
 static gchar *
-print_rc_style (GtkWidget * win, gchar * name, gchar * state,
+print_rc_style (GtkWidget * win, const gchar * name, const gchar * state,
 		GtkStyle * style)
 {
     gchar *s;
@@ -159,7 +161,7 @@ print_rc_style (GtkWidget * win, gchar * name, gchar * state,
 }
 
 gchar *
-get_style (GtkWidget * win, gchar * name, gchar * state)
+get_style (GtkWidget * win, const gchar * name, const gchar * state)
 {
     GtkStyle *style = NULL;
     gchar *s = NULL;
@@ -181,7 +183,7 @@ get_style (GtkWidget * win, gchar * name, gchar * state)
 }
 
 static GdkGC *
-_get_style_gc (gchar * name, gchar * state, GtkStyle * style)
+_get_style_gc (const gchar * name, const gchar * state, GtkStyle * style)
 {
     GdkGC *gc = NULL;
     gint n, m;
@@ -224,7 +226,7 @@ _get_style_gc (gchar * name, gchar * state, GtkStyle * style)
 }
 
 GdkGC *
-get_style_gc (GtkWidget * win, gchar * name, gchar * state)
+get_style_gc (GtkWidget * win, const gchar * name, const gchar * state)
 {
     GtkStyle *style = NULL;
 
