@@ -13,15 +13,16 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef NETK_WINDOW_H
 #define NETK_WINDOW_H
 
+#if defined(LIBXFCEGUI4_COMPILATION) || !defined(XFCE_DISABLE_DEPRECATED)
+
 #include <glib-object.h>
 #include <libxfcegui4/netk-screen.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -216,4 +217,7 @@ gboolean netk_window_is_in_viewport (NetkWindow * window,
                                      NetkWorkspace * workspace);
 
 G_END_DECLS
+
+#endif /* !XFCE_DISABLE_DEPRECATED */
+
 #endif /* NETK_WINDOW_H */
