@@ -13,10 +13,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,6 +33,8 @@
 #include "netk-xutils.h"
 #include "netk-private.h"
 
+#define NETK_WORKSPACE_GET_PRIVATE(o)    (G_TYPE_INSTANCE_GET_PRIVATE ((o), NETK_TYPE_WORKSPACE, NetkWorkspacePrivate))
+
 struct _NetkWorkspacePrivate
 {
     NetkScreen *screen;
@@ -57,43 +58,33 @@ static void netk_workspace_finalize (GObject * object);
 
 static void emit_name_changed (NetkWorkspace * space);
 
-static gpointer parent_class;
+static GObjectClass *parent_class;
 static guint signals[LAST_SIGNAL] = { 0 };
 
 GType
 netk_workspace_get_type (void)
 {
-    static GType object_type = 0;
+    static GType type = G_TYPE_INVALID;
 
-    g_type_init ();
-
-    if (!object_type)
+    if (G_UNLIKELY (type == G_TYPE_INVALID))
     {
-        static const GTypeInfo object_info = {
-            sizeof (NetkWorkspaceClass),
-            (GBaseInitFunc) NULL,
-            (GBaseFinalizeFunc) NULL,
-            (GClassInitFunc) netk_workspace_class_init,
-            NULL,               /* class_finalize */
-            NULL,               /* class_data */
-            sizeof (NetkWorkspace),
-            0,                  /* n_preallocs */
-            (GInstanceInitFunc) netk_workspace_init,
-        };
-
-        object_type =
-            g_type_register_static (G_TYPE_OBJECT, "NetkWorkspace",
-                                    &object_info, 0);
+        type = _netk_g_type_register_simple (G_TYPE_OBJECT,
+                                             "NetkWorkspace",
+                                             sizeof (NetkWorkspaceClass),
+                                             netk_workspace_class_init,
+                                             sizeof (NetkWorkspace),
+                                             netk_workspace_init,
+                                             0);
     }
 
-    return object_type;
+    return type;
 }
 
 static void
 netk_workspace_init (NetkWorkspace * workspace)
 {
-    workspace->priv = g_new0 (NetkWorkspacePrivate, 1);
-
+    workspace->priv = NETK_WORKSPACE_GET_PRIVATE (workspace);
+    
     workspace->priv->number = -1;
 }
 
@@ -101,13 +92,15 @@ static void
 netk_workspace_class_init (NetkWorkspaceClass * klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
+    
+    g_type_class_add_private (klass, sizeof (NetkWorkspacePrivate));
 
     parent_class = g_type_class_peek_parent (klass);
 
     object_class->finalize = netk_workspace_finalize;
 
     signals[NAME_CHANGED] =
-        g_signal_new ("name_changed", G_OBJECT_CLASS_TYPE (object_class),
+        g_signal_new (I_("name_changed"), G_OBJECT_CLASS_TYPE (object_class),
                       G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (NetkWorkspaceClass,
                                                           name_changed), NULL,
                       NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
@@ -122,8 +115,6 @@ netk_workspace_finalize (GObject * object)
 
     g_free (workspace->priv->name);
 
-    g_free (workspace->priv);
-
     G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
