@@ -11,10 +11,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -837,9 +836,11 @@ void client_session_free(SessionClient * session_client)
     /* session_client->data; */
     /* session_client->session_connection; */
     
+#ifdef HAVE_LIBSM
     if (session_client->current_state != SESSION_CLIENT_DISCONNECTED) {
         disconnect(session_client);
     }
+#endif /* HAVE_LIBSM */
 
     g_free(session_client->client_id);
     g_free(session_client->given_client_id);
@@ -916,24 +917,67 @@ void client_session_set_data(SessionClient * session_client, gpointer value)
 
 void client_session_set_restart_style(SessionClient * session_client, SessionRestartStyle value)
 {
-    if (session_client->session_connection != NULL) {
-        g_error("SessionClient: changing \"restart_style\" while connected to session manager is not implemented.");
-        return;
-    }
-    
+#ifdef HAVE_LIBSM
+    SmProp prop, *props[1];
+    SmPropValue propval;
+    char hint = SmRestartIfRunning;
+#endif /* HAVE_LIBSM */    
     session_client->restart_style = value;
+
+#ifdef HAVE_LIBSM
+    if (session_client->session_connection != NULL) {
+        switch (session_client->restart_style) {
+            case SESSION_RESTART_IF_RUNNING:
+                hint = SmRestartIfRunning;
+                break;
+            case SESSION_RESTART_ANYWAY:
+                hint = SmRestartAnyway;
+                break;
+            case SESSION_RESTART_IMMEDIATELY:
+                hint = SmRestartImmediately;
+                break;
+            case SESSION_RESTART_NEVER:
+            default:
+                hint = SmRestartNever;
+                break;
+        }
+
+        prop.name = SmRestartStyleHint;
+        prop.type = SmCARD8;
+        prop.num_vals = 1;
+        prop.vals = &propval;
+        propval.value = &hint;
+        propval.length = 1;
+        props[0] = &prop;
+
+        SmcSetProperties ((SmcConn) session_client->session_connection, 1, props);
+    }
+#endif /* HAVE_LIBSM */    
 }
 
 /* void client_session_set_interact_style(SessionClient * session_client, SessionInteractStyle value) */
 
 void client_session_set_priority(SessionClient * session_client, gchar value)
 {
-    if (session_client->session_connection != NULL) {
-        g_error("SessionClient: changing \"priority\" while connected to session manager is not implemented.");
-        return;
-    }
-    
+#ifdef HAVE_LIBSM
+    SmProp prop, *props[1];
+    SmPropValue propval;
+#endif /* HAVE_LIBSM */    
+
     session_client->priority = value;
+#ifdef HAVE_LIBSM
+    if (session_client->session_connection != NULL) {
+        prop.name = "_GSM_Priority";
+        prop.type = SmCARD8;
+        prop.num_vals = 1;
+        prop.vals = &propval;
+        propval.value = &session_client->priority;
+        propval.length = 1;
+        props[0] = &prop;
+
+        SmcSetProperties ((SmcConn) session_client->session_connection, 1, props);
+    }
+#endif /* HAVE_LIBSM */    
 }
 
 void client_session_set_client_id(SessionClient * session_client, gchar const* value)
@@ -953,28 +997,61 @@ void client_session_set_client_id(SessionClient * session_client, gchar const* v
 
 void client_session_set_current_directory(SessionClient * session_client, gchar const* value)
 {
-    if (session_client->session_connection != NULL) {
-        g_error("SessionClient: changing \"current_directory\" while connected to session manager is not implemented.");
-        return;
-    }
-    
+#ifdef HAVE_LIBSM
+    SmProp prop, *props[1];
+    SmPropValue propval;
+#endif /* HAVE_LIBSM */    
+
     if (session_client->current_directory != value) {
         g_free(session_client->current_directory);
-        session_client->current_directory = g_strdup(value);
+        session_client->current_directory = NULL;
+        if (value) {
+            session_client->current_directory = g_strdup(value);
+        }
     }
+#ifdef HAVE_LIBSM
+    if (session_client->session_connection != NULL) {
+        prop.name = SmCurrentDirectory;
+        prop.type = SmARRAY8;
+        prop.num_vals = 1;
+        prop.vals = &propval;
+        if (session_client->current_directory) {
+            propval.value = (char *) session_client->current_directory;
+        }
+        else {
+            propval.value = (char *) g_get_home_dir ();
+        }
+        propval.length = strlen (propval.value);
+        props[0] = &prop;
+
+        SmcSetProperties ((SmcConn) session_client->session_connection, 1, props);
+    }
+#endif /* HAVE_LIBSM */    
 }
 
 void client_session_set_program(SessionClient * session_client, gchar const* value)
 {
-    if (session_client->session_connection != NULL) {
-        g_error("SessionClient: changing \"program\" while connected to session manager is not implemented.");
-        return;
-    }
+#ifdef HAVE_LIBSM
+    SmProp prop, *props[1];
+    SmPropValue propval;
+#endif /* HAVE_LIBSM */    
     
     if (session_client->program != value) {
         g_free(session_client->program);
         session_client->program = g_strdup(value);
     }
+#ifdef HAVE_LIBSM
+    if (session_client->session_connection != NULL) {
+        prop.name = SmProgram;
+        prop.type = SmARRAY8;
+        prop.num_vals = 1;
+        prop.vals = &propval;
+        propval.value = session_client->program;
+        propval.length = strlen (session_client->program);
+
+        SmcSetProperties ((SmcConn) session_client->session_connection, 1, props);
+    }
+#endif /* HAVE_LIBSM */    
 }
 
 void client_session_set_clone_command(SessionClient * session_client, gchar** const value)
