@@ -1,4 +1,4 @@
-/* $Id: xfce-heading.c 21491 2006-05-04 21:23:29Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2006 Benedikt Meurer <benny@xfce.org>.
  *
@@ -12,10 +12,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -53,8 +52,6 @@ enum
 
 
 
-static void         xfce_heading_class_init     (XfceHeadingClass *klass);
-static void         xfce_heading_init           (XfceHeading      *heading);
 static void         xfce_heading_finalize       (GObject          *object);
 static void         xfce_heading_get_property   (GObject          *object,
                                                  guint             prop_id,
