@@ -1,4 +1,4 @@
-/* $Id: xfce_aboutdialog.h 21424 2006-05-01 15:09:21Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2002-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -13,15 +13,16 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef __LIBXFCEGUI4_XFCE_ABOUTDIALOG_H__
 #define __LIBXFCEGUI4_XFCE_ABOUTDIALOG_H__
 
+#if defined(LIBXFCEGUI4_COMPILATION) || !defined(XFCE_DISABLE_DEPRECATED)
+
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
@@ -133,4 +134,6 @@ GdkPixbuf   *xfce_about_dialog_get_icon(XfceAboutDialog* dialog);
 
 G_END_DECLS;
 
+#endif /* !XFCE_DISABLE_DEPRECATED */
+
 #endif  /* !__LIBXFCEGUI4_XFCE_ABOUTDIALOG_H__ */
