@@ -11,10 +11,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,7 +23,7 @@
 #include <gdk/gdk.h>
 #include <gtk/gtkmisc.h>
 
-#include "xfce_decortoggle.h"
+#include <libxfcegui4/libxfcegui4.h>
 
 #define DECORTOGGLE_WIDTH  10
 #define DECORTOGGLE_HEIGHT 10
@@ -32,60 +31,56 @@
 #define decortoggle_WIDTH  10
 #define decortoggle_HEIGHT 10
 
-static unsigned char arrow_up_dark_bits[] = {
+static const unsigned char arrow_up_dark_bits[] = {
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x18, 0x00, 0x0c, 0x00,
     0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 };
-static unsigned char arrow_up_mid_bits[] = {
+static const unsigned char arrow_up_mid_bits[] = {
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0x70, 0x00,
     0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 };
-static unsigned char arrow_up_light_bits[] = {
+static const unsigned char arrow_up_light_bits[] = {
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
     0x00, 0x00, 0xfc, 0x01, 0x00, 0x00, 0x00, 0x00,
 };
-static unsigned char arrow_down_dark_bits[] = {
+static const unsigned char arrow_down_dark_bits[] = {
     0x00, 0x00, 0x00, 0x00, 0xfe, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 };
-static unsigned char arrow_down_mid_bits[] = {
+static const unsigned char arrow_down_mid_bits[] = {
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7c, 0x00, 0x38, 0x00, 0x10, 0x00,
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 };
-static unsigned char arrow_down_light_bits[] = {
+static const unsigned char arrow_down_light_bits[] = {
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0xc0, 0x00, 0x60, 0x00,
     0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 };
-static unsigned char arrow_left_dark_bits[] = {
+static const unsigned char arrow_left_dark_bits[] = {
     0x00, 0x00, 0x20, 0x00, 0x30, 0x00, 0x18, 0x00, 0x0c, 0x00, 0x00, 0x00,
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 };
-static unsigned char arrow_left_mid_bits[] = {
+static const unsigned char arrow_left_mid_bits[] = {
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0x30, 0x00, 0x38, 0x00,
     0x30, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00,
 };
-static unsigned char arrow_left_light_bits[] = {
+static const unsigned char arrow_left_light_bits[] = {
     0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x40, 0x00, 0x40, 0x00, 0x40, 0x00,
     0x40, 0x00, 0x40, 0x00, 0x40, 0x00, 0x00, 0x00,
 };
-static unsigned char arrow_right_dark_bits[] = {
+static const unsigned char arrow_right_dark_bits[] = {
     0x00, 0x00, 0x08, 0x00, 0x08, 0x00, 0x08, 0x00, 0x08, 0x00, 0x08, 0x00,
     0x08, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00,
 };
-static unsigned char arrow_right_mid_bits[] = {
+static const unsigned char arrow_right_mid_bits[] = {
     0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x30, 0x00, 0x70, 0x00, 0x30, 0x00,
     0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 };
-static unsigned char arrow_right_light_bits[] = {
+static const unsigned char arrow_right_light_bits[] = {
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00,
     0x60, 0x00, 0x30, 0x00, 0x10, 0x00, 0x00, 0x00,
 };
 
 /* Forward declarations */
-
-static void xfce_decortoggle_class_init (XfceDecortoggleClass * class);
-static void xfce_decortoggle_init (XfceDecortoggle * decortoggle);
-static void xfce_decortoggle_destroy (GtkObject * object);
 static void xfce_decortoggle_finalize (GObject * object);
 static void xfce_decortoggle_size_request (GtkWidget * widget,
 					   GtkRequisition * requisition);
@@ -94,36 +89,7 @@ static gint xfce_decortoggle_expose (GtkWidget * widget,
 static void xfce_decortoggle_draw (GtkWidget * widget, GdkRectangle * area);
 
 /* Local data */
-
-static GtkWidgetClass *parent_class = NULL;
-
-GtkType
-xfce_decortoggle_get_type (void)
-{
-    static GtkType decortoggle_type = 0;
-
-    if (!decortoggle_type)
-    {
-	static const GTypeInfo decortoggle_info = {
-	    sizeof (XfceDecortoggleClass),
-	    NULL,		/* base_init */
-	    NULL,		/* base_finalize */
-	    (GClassInitFunc) xfce_decortoggle_class_init,
-	    NULL,		/* class_finalize */
-	    NULL,		/* class_data */
-	    sizeof (XfceDecortoggle),
-	    0,			/* n_preallocs */
-	    (GInstanceInitFunc) xfce_decortoggle_init,
-	    NULL		/* value_table */
-	};
-
-	decortoggle_type =
-	    g_type_register_static (GTK_TYPE_MISC, "XfceDecortoggle",
-				    &decortoggle_info, 0);
-    }
-
-    return decortoggle_type;
-}
+G_DEFINE_TYPE (XfceDecortoggle, xfce_decortoggle, GTK_TYPE_MISC)
 
 static void
 xfce_decortoggle_class_init (XfceDecortoggleClass * class)
@@ -136,10 +102,7 @@ xfce_decortoggle_class_init (XfceDecortoggleClass * class)
     widget_class = (GtkWidgetClass *) class;
     gobject_class = G_OBJECT_CLASS (class);
 
-    parent_class = gtk_type_class (gtk_misc_get_type ());
-
     widget_class->size_request = xfce_decortoggle_size_request;
-    object_class->destroy = xfce_decortoggle_destroy;
     gobject_class->finalize = xfce_decortoggle_finalize;
 
     widget_class->expose_event = xfce_decortoggle_expose;
@@ -177,16 +140,6 @@ xfce_decortoggle_new (GtkArrowType arrow_type)
     return GTK_WIDGET (decortoggle);
 }
 
-static void
-xfce_decortoggle_destroy (GtkObject * object)
-{
-    g_return_if_fail (object != NULL);
-    g_return_if_fail (XFCE_IS_DECORTOGGLE (object));
-
-    if (GTK_OBJECT_CLASS (parent_class)->destroy)
-	(*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
-}
-
 static void
 xfce_decortoggle_finalize (GObject * object)
 {
@@ -261,7 +214,7 @@ xfce_decortoggle_finalize (GObject * object)
 	decortoggle->arrow_right_light_bmap = NULL;
     }
     decortoggle->initialized = FALSE;
-    G_OBJECT_CLASS (parent_class)->finalize (object);
+    G_OBJECT_CLASS (xfce_decortoggle_parent_class)->finalize (object);
 }
 
 static void
