@@ -11,10 +11,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,53 +30,18 @@
 
 /* Forward declarations */
 
-static void xfce_framebox_class_init (XfceFrameboxClass * class);
-
 /* Local data */
-
-static GtkWidgetClass *parent_class = NULL;
-
-GtkType
-xfce_framebox_get_type (void)
-{
-    static GtkType framebox_type = 0;
-
-    if (!framebox_type)
-    {
-        static const GTypeInfo framebox_info = {
-            sizeof (XfceFrameboxClass),
-            NULL,               /* base_init */
-            NULL,               /* base_finalize */
-            (GClassInitFunc) xfce_framebox_class_init,
-            NULL,               /* class_finalize */
-            NULL,               /* class_data */
-            sizeof (XfceFramebox),
-            0,                  /* n_preallocs */
-            NULL,               /* instance_init */
-            NULL                /* value_table */
-        };
-
-        framebox_type =
-            g_type_register_static (GTK_TYPE_FRAME,
-                                    "XfceFramebox", &framebox_info,
-                                    0);
-    }
-
-    return framebox_type;
-}
+G_DEFINE_TYPE (XfceFramebox, xfce_framebox, GTK_TYPE_FRAME)
 
 static void
 xfce_framebox_class_init (XfceFrameboxClass * class)
 {
-    GObjectClass *gobject_class = G_OBJECT_CLASS (class);
-    GtkObjectClass *object_class;
-    GtkWidgetClass *widget_class;
 
-    object_class = (GtkObjectClass *) class;
-    widget_class = (GtkWidgetClass *) class;
-    gobject_class = G_OBJECT_CLASS (class);
+}
 
-    parent_class = gtk_type_class (gtk_frame_get_type ());
+static void
+xfce_framebox_init (XfceFramebox * box)
+{
 }
 
 /**
