@@ -11,15 +11,16 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef __XFCE_FRAMEBOX_H__
 #define __XFCE_FRAMEBOX_H__
 
+#if defined(LIBXFCEGUI4_COMPILATION) || !defined(XFCE_DISABLE_DEPRECATED)
+
 #include <gdk/gdk.h>
 #include <gtk/gtkframe.h>
 
@@ -45,16 +46,15 @@ G_BEGIN_DECLS
         GtkFrameClass parent_class;
     };
 
-#ifndef XFCE_DISABLE_DEPRECATED
-
     GType xfce_framebox_get_type        (void) G_GNUC_CONST;
     GtkWidget *xfce_framebox_new        (const gchar *text,
                                          gboolean indent);
     
     void xfce_framebox_add              (XfceFramebox *framebox, 
                                          GtkWidget *widget);
-#endif
 
 G_END_DECLS
 
+#endif /* !XFCE_DISABLE_DEPRECATED */
+
 #endif                          /* __XFCE_FRAMEBOX_H__ */
