@@ -11,10 +11,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 
@@ -77,9 +76,7 @@ xineramaFree (void)
 gint
 xineramaGetHeads (void)
 {
-    GdkScreen *gscr = gdk_screen_get_default ();
-    g_return_val_if_fail (gscr, 0);
-    return (gdk_screen_get_n_monitors (gscr));
+    return gdk_screen_get_n_monitors (gdk_screen_get_default ());
 }
 
 /**
@@ -98,9 +95,7 @@ xineramaGetHeads (void)
 gint
 MyDisplayFullHeight (Display * dpy, int screen)
 {
-    GdkScreen *gscr = gdk_screen_get_default ();
-    g_return_val_if_fail (gscr, 0);
-    return (gdk_screen_get_height (gscr));
+    return gdk_screen_get_height (gdk_screen_get_default ());
 }
 
 /**
@@ -119,21 +114,15 @@ MyDisplayFullHeight (Display * dpy, int screen)
 gint
 MyDisplayFullWidth (Display * dpy, int screen)
 {
-    GdkScreen *gscr = gdk_screen_get_default ();
-    g_return_val_if_fail (gscr, 0);
-    return (gdk_screen_get_width (gscr));
+    return gdk_screen_get_width (gdk_screen_get_default ());
 }
 
 
-static gboolean
+static void
 getGeometry (gint x, gint y, GdkRectangle *rect)
 {
     GdkScreen *gscr = gdk_screen_get_default ();
-    gint monitor_nbr;
-    g_return_val_if_fail (gscr, FALSE);
-    monitor_nbr = gdk_screen_get_monitor_at_point (gscr, x, y);
-    gdk_screen_get_monitor_geometry (gscr, monitor_nbr, rect);
-    return TRUE;
+    gdk_screen_get_monitor_geometry (gscr, gdk_screen_get_monitor_at_point (gscr, x, y), rect);
 }
 
 /**
@@ -155,10 +144,8 @@ gint
 MyDisplayHeight (Display * dpy, int screen, gint x, gint y)
 {
     GdkRectangle rect;
-    gboolean success;
-    success = getGeometry (x, y, &rect);
-    g_return_val_if_fail (success, 0);
-    return (rect.height);
+    getGeometry (x, y, &rect);
+    return rect.height;
 }
 
 /**
@@ -180,10 +167,8 @@ gint
 MyDisplayWidth (Display * dpy, int screen, gint x, gint y)
 {
     GdkRectangle rect;
-    gboolean success;
-    success = getGeometry (x, y, &rect);
-    g_return_val_if_fail (success, 0);
-    return (rect.width);
+    getGeometry (x, y, &rect);
+    return rect.width;
 }
 
 /**
@@ -203,10 +188,8 @@ gint
 MyDisplayX (gint x, gint y)
 {
     GdkRectangle rect;
-    gboolean success;
-    success = getGeometry (x, y, &rect);
-    g_return_val_if_fail (success, 0);
-    return (rect.x);
+    getGeometry (x, y, &rect);
+    return rect.x;
 }
 
 /**
@@ -226,10 +209,8 @@ gint
 MyDisplayY (gint x, gint y)
 {
     GdkRectangle rect;
-    gboolean success;
-    success = getGeometry (x, y, &rect);
-    g_return_val_if_fail (success, 0);
-    return (rect.y);
+    getGeometry (x, y, &rect);
+    return rect.y;
 }
 
 /**
@@ -251,10 +232,8 @@ gint
 MyDisplayMaxX (Display * dpy, int screen, gint x, gint y)
 {
     GdkRectangle rect;
-    gboolean success;
-    success = getGeometry (x, y, &rect);
-    g_return_val_if_fail (success, 0);
-    return (rect.x + rect.width);
+    getGeometry (x, y, &rect);
+    return rect.x + rect.width;
 }
 
 /**
@@ -276,10 +255,8 @@ gint
 MyDisplayMaxY (Display * dpy, int screen, gint x, gint y)
 {
     GdkRectangle rect;
-    gboolean success;
-    success = getGeometry (x, y, &rect);
-    g_return_val_if_fail (success, 0);
-    return (rect.y + rect.height);
+    getGeometry (x, y, &rect);
+    return rect.y + rect.height;
 }
 
 /**
@@ -301,8 +278,7 @@ MyDisplayMaxY (Display * dpy, int screen, gint x, gint y)
 gboolean
 isRightMostHead (Display * dpy, int screen, gint x, gint y)
 {
-    return (MyDisplayMaxX (dpy, screen, x, y) 
-            == MyDisplayFullWidth (dpy, screen));
+    return (MyDisplayMaxX (dpy, screen, x, y) == MyDisplayFullWidth (dpy, screen));
 }
 
 /**
@@ -368,6 +344,5 @@ isTopMostHead (Display * dpy, int screen, gint x, gint y)
 gboolean
 isBottomMostHead (Display * dpy, int screen, gint x, gint y)
 {
-    return (MyDisplayMaxY (dpy, screen, x, y) 
-            == MyDisplayFullHeight (dpy, screen));
+    return (MyDisplayMaxY (dpy, screen, x, y) == MyDisplayFullHeight (dpy, screen));
 }
